.. _tutorials:

PyNeon Tutorials
================

Here you can find tutorials in the form of Jupyter notebooks to help you get
started with PyNeon.

.. toctree::
    :maxdepth: 1

    read_recording_cloud
    read_recording_native
    interpolate_and_concat
    pupil_size_and_epoching
    surface_mapping
    video
    export_to_bids